multidim.covertree.CoverTree.make_edges — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverTree.make_edges

`CoverTree.` `make_edges`(min_distance=0.0, max_distance=-1.0)

  Iterate over the edges between the points of the underlying `PointCloud`, where min_distance < length <= max_distance.

  Uses the CoverTree type-1 friends for efficiency. This is called by `PointCloud.build_edges()`

  Parameters: | min_distance: float Minimum length. (Default: 0.0) Inequality means no self-edges! max_distance: float Maximum length. (Default: -1.0, meaning 2*self._r0, for all edges)
  Yields: | triples (a,b,r), where a,b are the indices of points, and r is the distance.

#### Previous topic

multidim.covertree.CoverTree

#### Next topic

multidim.covertree.CoverTree.next